# -*- coding: utf-8 -*-
"""TODO: DOCSTRING."""

import pyglet


class GraphX(object):
    """A graphics manager for the game, this includes colors, tiles, etc..."""

    def __init__(self):
        """Init graphx manager."""
        pass
